# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorarch: %global perl_vendorarch %(eval "`perl -V:installvendorarch`"; echo $installvendorarch)}

# A noarch-turned-arch package should not have debuginfo
%global debug_package %{nil}

# Fix up RPM/CPAN versioning incompatibilities
%global cpanversion 6.14
%global rpmversion 6.14

# Convenient function for distro testing
%define fedora_rhel_later_than() %([ \\( "%{__distinit}" = "fc" -a %{__distvers} -gt %1 \\) -o \\( "%{__distinit}" = "rhel" -a %{__distvers} -gt %2 \\) ] && echo 1 || echo 0)

Name:		perl-AnyEvent
Version:	%{rpmversion}
Release:	3.%{__distinit}%{__distvers}
Summary:	Framework for multiple event loops
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/AnyEvent/
Source0:	http://search.cpan.org/CPAN/authors/id/M/ML/MLEHMANN/AnyEvent-%{cpanversion}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# Build requirements
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module requirements
BuildRequires:	perl >= 3:5.8.1
BuildRequires:	perl(Carp)
BuildRequires:	perl(Task::Weaken)
BuildRequires:	perl(Time::HiRes)
# Test suite requirements
BuildRequires:	perl(Net::SSLeay)
BuildRequires:	perl(Test::More)
# Event loop testing (Cocoa and FLTK are not in Fedora/EPEL)
# EV -> AnyEvent
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(EV)
%endif
BuildRequires:	perl(Event)
%if %fedora_rhel_later_than 7 5
BuildRequires:	perl(Event::Lib)
%endif
%if %fedora_rhel_later_than 12 5
BuildRequires:	perl(Glib) >= 1.210
%endif
# Version of IO::Async::Loop in Fedora is too old
#TODO: BuildRequires:	perl(IO::Async::Loop) >= 0.33
# POE 1.289 in F-16 and all older versions fail tests 10-12 of t/68_poe_09_multi.t
# POE 1.312 in F-17 works OK
%if %fedora_rhel_later_than 16 6
BuildRequires:	perl(POE) >= 1.312
%endif
# Tk fails to load prior to F-9/EL-6, for reasons unknown
%if %fedora_rhel_later_than 8 5 
BuildRequires:	perl(Tk)
%endif
# Runtime requires
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
# Optional but recommended
Requires:	perl(Task::Weaken)

# Optional dependencies we don't want to require
%global optional_deps ^perl[(](Cocoa::EventLoop|EV|Event|Event::Lib|FLTK|Glib|IO::Async::Loop|Irssi|Net::SSLeay|POE|Qt|Qt::isa|Qt::slots|Tk)[)]

# Don't include optional dependencies (rpm 4.9 onwards)
%global __requires_exclude %{optional_deps}

# Filter unversioned and bogus provides(rpm 4.9 onwards)
%global __provides_exclude ^perl[(](AnyEvent|DB)[)]$

%description
AnyEvent provides an identical interface to multiple event loops. This allows
module authors to utilize an event loop without forcing module users to use the
same event loop (as multiple event loops cannot coexist peacefully at any one
time).

%prep
%setup -q -n AnyEvent-%{cpanversion}

# Don't include optional dependencies (prior to rpm 4.9)
%global perl_reqfilt /bin/sh -c "%{__perl_requires} | grep -Ev '%{optional_deps}'"
%define __perl_requires %{perl_reqfilt}

# Filter unversioned provide where we have a versioned one (perl 5.8.6 onwards, rpm < 4.9)
# Filter bogus provide of perl(DB) anyway
%if %(perl -e 'print (($] >= 5.008006) ? 1 : 0)')
%global perl_provfilt /bin/sh -c "%{__perl_provides} | grep -Evx 'perl[(](AnyEvent|DB)[)]'"
%else
%global perl_provfilt /bin/sh -c "%{__perl_provides} | grep -Fvx 'perl(DB)'"
%endif
%define __perl_provides %{perl_provfilt}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -depth -type d -exec rmdir {} \; 2>/dev/null
%{_fixperms} %{buildroot}

%check
PERL_ANYEVENT_LOOP_TESTS=1 PERL_ANYEVENT_NET_TESTS=1 make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes COPYING README
%{perl_vendorarch}/AE.pm
%{perl_vendorarch}/AnyEvent.pm
%{perl_vendorarch}/AnyEvent/
%{_mandir}/man3/AE.3pm*
%{_mandir}/man3/AnyEvent.3pm*
%{_mandir}/man3/AnyEvent::DNS.3pm*
%{_mandir}/man3/AnyEvent::Debug.3pm*
%{_mandir}/man3/AnyEvent::FAQ.3pm*
%{_mandir}/man3/AnyEvent::Handle.3pm*
%{_mandir}/man3/AnyEvent::Impl::Cocoa.3pm*
%{_mandir}/man3/AnyEvent::Impl::EV.3pm*
%{_mandir}/man3/AnyEvent::Impl::Event.3pm*
%{_mandir}/man3/AnyEvent::Impl::EventLib.3pm*
%{_mandir}/man3/AnyEvent::Impl::FLTK.3pm*
%{_mandir}/man3/AnyEvent::Impl::Glib.3pm*
%{_mandir}/man3/AnyEvent::Impl::IOAsync.3pm*
%{_mandir}/man3/AnyEvent::Impl::Irssi.3pm*
%{_mandir}/man3/AnyEvent::Impl::POE.3pm*
%{_mandir}/man3/AnyEvent::Impl::Perl.3pm*
%{_mandir}/man3/AnyEvent::Impl::Qt.3pm*
%{_mandir}/man3/AnyEvent::Impl::Tk.3pm*
%{_mandir}/man3/AnyEvent::Intro.3pm*
%{_mandir}/man3/AnyEvent::Log.3pm*
%{_mandir}/man3/AnyEvent::Loop.3pm*
%{_mandir}/man3/AnyEvent::Socket.3pm*
%{_mandir}/man3/AnyEvent::Strict.3pm*
%{_mandir}/man3/AnyEvent::TLS.3pm*
%{_mandir}/man3/AnyEvent::Util.3pm*

%changelog
* Fri Feb 10 2012 Paul Howarth <paul@city-fan.org> - 6.14-3
- Don't BR: perl(EV) if we're bootstrapping

* Wed Feb  1 2012 Paul Howarth <paul@city-fan.org> - 6.14-2
- Reinstate perl(Tk) as a buildreq now that it can actually load

* Tue Jan 31 2012 Paul Howarth <paul@city-fan.org> - 6.14-1
- Update to 6.14:
  - AnyEvent::Impl::Tk was broken due to a mysterious "die" inside, probably an
    editing mistake

* Thu Jan 12 2012 Paul Howarth <paul@city-fan.org> - 6.13-1
- Update to 6.13:
  - AnyEvent::Util::fork_call checked for POSIX availability in the wrong way,
    causing it to fail if POSIX wasn't loaded already
  - AnyEvent::Handle::push_read (line => ...) did pass $1 directly, so
    regex-matching inside the callback would change the parameter, despite
    $1 being dynamically scoped per-block; this perl bug is now being worked
    around

* Mon Dec 12 2011 Paul Howarth <paul@city-fan.org> - 6.12-1
- Update to 6.12:
  - $! was clobbered by subsequent calls in tcp_connect, due to the postpone
    not saving/restoring it

* Tue Nov 22 2011 Paul Howarth <paul@city-fan.org> - 6.11-1
- Update to 6.11:
  - Tk cannot create windows when tainted unless you set a title, so set a
    dummy title for AnyEvent's dummy mainwindow
  - Escape any non-printable/non-ascii characters when stringifying backtraces
  - Log the reason loading an interface module fails to load at level debug
- Drop perl(Tk) buildreq as the Tk module just doesn't seem to want to load

* Tue Oct  4 2011 Paul Howarth <paul@city-fan.org> - 6.10-1
- Update to 6.1:
  - INCOMPATIBLE CHANGE: the default log level is now "4" (error and above),
    and some messages inside AnyEvent have been elevated to higher log levels
    to print by default
  - AnyEvent::log, unlike AnyEvent::Log::log, did not always exit on fatal
  - Work around yet another signal race bug, newly introduced by POE
  - Add google public ipv6 dns as fallback servers, so AE::DNS can finally
    support ipv6-only operation even with defaults (also use ::1 instead of
    127.0.0.1)
  - Give better guidelines on how to choose a logging level
  - AnyEvent::Log can now cap (limit) log message priority by context
  - AE::log will now save and restore $! and $@, so callers don't have to
  - AE::Strict now checks that registered fds are still valid at regular
    intervals
  - Skip frequently called 'require' calls if the module appears loaded
  - Increase signal latency test timer considerably for poor little OSX, which
    can't be bothered with basic POSIX functionality such as signal delivery
  - Mention some debugging aides in the tutorial
  - New environment variable PERL_ANYEVENT_MAX_SIGNAL_LATENCY
  - Private (%%namespace) log contexts in PERL_ANYEVENT_LOG now have the name
    of the context as title
  - AnyEvent::Strict would not restore read-write access to $_ when a callback
    died - this is a user bug, but since AE::Strict exists to help dbeugging...
  - Detect the extremely evil IO::Async::Loop::AnyEvent module and refuse to
    work with it - the author is well aware of the issues but refuses to fix
    them; this extreme step has been taken because the module actively attacks
    the goals of AnyEvent and makes it harder for module authors to use
    AnyEvent
- BR: perl(Carp)

* Fri Aug 26 2011 Paul Howarth <paul@city-fan.org> - 6.02-1
- Update to 6.02:
  - log_to_syslog now accepts facility strings.
  - log_to_syslog would not allow facilities - "$facility|$level" *literally*
    means that string
  - The CPAN parser got confused and thought we provide Sys::Syslog; try to
    work around it
  - Rename AnyEvent::Impl::FLTK2 to FLTK

* Fri Aug 26 2011 Paul Howarth <paul@city-fan.org> - 6.01-1
- Update to 6.01:
  - INCOMPATIBLE CHANGE: Verbosity levels have been redefined; see AnyEvent
    (PERL_ANYEVENT_VERBOSE) and AnyEvent::Log for details
  - New function: AnyEvent::log
  - New module: AnyEvent::Log, for simple logging needs
  - New env variable, PERL_ANYEVENT_LOG, for fine-grained logging config
  - New env variable, PERL_ANYEVENT_HOSTS, to override the place where the
    /etc/hosts file can be found
  - An empty PERL_ANYEVENT_RESOLV_CONF now selects the default configuration
  - Environment variables can now be specified using AE_xyz instead of
    PERL_ANYEVENT_xyz, subject to some rules
  - Lots of new AnyEvent::Debug functionality
  - AnyEvent::Strict now checks for modifications of $_ by the callback (by
    setting it to readonly while executing the callback, if possible)
  - AnyEvent::Socket::resolve_sockaddr and all functions using it now support
    /etc/hosts overrides
  - Do not run event loop detection multiple times when programs call their
    cached copies of AnyEvent::detect
  - parse_hostport now accepts absolute paths as unix domain sockets
  - Suppress the idiotic warning inside POE by patching the POE::Kernel run
    flags instead of asking the user to jump through contortions
  - Add Task::Weaken as dependency (as recommends only at this time)
  - Replace PF_UNSPEC by 0, for good old Minix
- Drop now-redundant patch removing FLTK2 references
- Package manpages for AnyEvent::Impl::FLTK2 and AnyEvent::Log
- BR/R: perl(Task::Weaken)
- BR: perl(Net::SSLeay) unconditionally as although the test still emits a
  "Too late to run CHECK block" warning prior to perl 5.10, the test still
  passes
- BR: perl(Event::Lib), perl(Glib) ≥ 1.210, perl(POE) and perl(Tk) where
  possible (i.e. pull in from Fedora/EPEL)
- BR: perl(Time::HiRes)
- Filter bogus provide of perl(DB)

* Sun Aug 14 2011 Paul Howarth <paul@city-fan.org> - 6.0-1
- Update to 6.0:
  - INCOMPATIBLE CHANGE: AnyEvent::DNS resource records now include the TTL as
    fourth element - this affects ->resolve directly, and ->request and
    ->dns_unpack indirectly; convenience functions such as
    AnyEvent::DNS::{a,txt,mx,srv} are not affected, and neither is
    AnyEvent::Socket
  - INCOMPATIBLE CHANGE: backend authors now should not implement one_event or
    loop, but instead the AnyEvent::CondVar::_wait and _poll methods
  - DEPRECATION: please change
    "use AnyEvent::Impl::Perl" to "use AnyEvent::Loop" and
    "AnyEvent::Impl::Perl::loop" to "AnyEvent::Loop::run" in your programs, for
    future compatibility
  - Idle watcher emulation was borked
  - AnyEvent::Strict now checks the AE::xxx functions as well
  - Querying too-long domain names would barf deep inside AnyEvent::DNS; since
    this is hard to avoid for applications, AnyEvent:.DNS::request now checks
    for too-long domain names explicitly and passes an undef to the callback
    instead
  - Make AnyEvent::Util more robust against EINTR
  - New function: AnyEvent::postpone
  - New env variable, PERL_ANYEVENT_DEBUG_SHELL, to automatically start a debug
    shell
  - New env variable, PERL_ANYEVENT_DEBUG_WRAP, to automatically enable watcher
    instrumentation/wrapping (see AnyEvent::Debug::wrap)
  - IO::Async sometimes cancels the wrong timer when you call cancel_timer;
    invest extra overhead to work around this peculiar behaviour
  - Split the pure perl backend into a loop module and an impl module
    (AnyEvent::Loop and AnyEvent::Impl::Perl)
  - Some read types (regex, netstring, json, storable) could errornously keep
    an AE::Handle object alive on their own
  - Add more workarounds around child watcher bugs in IO::Async and (newly
    introduced) in POE
  - Use glib child watchers and try to work around its limitations, if possible
  - Add support for FLTK (fltk2) via AnyEvent::Impl::FLTK2
  - Many read types in AnyEvent::Handle would malfunction during transitions to
    TLS because of a "delete $self->{rbuf}"
  - Improve condvar blocking wait performance (probably only noticable with
    faster backends) and also make it easier for event loops that do not
    support blocking waits
  - PERL_ANYEVENT_MODEL now also allows full module names, although the
    usefulness of this feature is not yet clear
  - Add tests for all supported event loops, conditional on
    PERL_ANYEVENT_LOOP_TESTS
  - Add t/80_ssltext.t
  - No longer use AUTOLOAD for the initial loading (for no very good reason)
  - tcp_server now tries to unlink unix domain sockets when it gets destroyed
- Patch AnyEvent::Impl::FLTK2 out of Makefile.PL as upstream forgot to ship it
- Package new manpage for AnyEvent::Loop
- Add new buildreqs for tests: perl(EV), perl(Event), perl(Net::SSLeay)

* Sat Jun 25 2011 Paul Howarth <paul@city-fan.org> - 5.34-3
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Jun 25 2011 Paul Howarth <paul@city-fan.org> - 5.34-2
- Fix filter for rpm 4.9.x not to blow away versioned perl(AnyEvent) provide

* Thu May 12 2011 Paul Howarth <paul@city-fan.org> - 5.34-1
- Update to 5.34:
  - AnyEvent::Handle on_connect_error - do not try to destroy a handle object
    when it's already gone
  - Update idna algorithm(s) to UTS#46 version 6.0.0
  - Preserve trailing dot in idn_to_ascii - testsuite says to preserve, uts46
    says it's an error, and testsuite makes more sense
  - Remove leading dots in idn_to_ascii - testsuite says to remove, uts46 says
    it's an error, and testsuite makes more sense
  - Fixed a bug in idn ignored character processing
  - Passes the uts46 6.0.0 testsuite except for three cases which apparently
    are bugs in the testsuite itself
  - Passes the uts46 6.0.1 testsuite except for eleven cases which apparently
    are bugs in the testsuite itself
  - AE::TLS didn't support both cert_file and key at the same time, due to some
    copy&paste bug
  - Improve AE::Handle timeout documentation slightly
- Nobody else likes macros for commands
- Tidy up dependency filters
- Filter unversioned provide of perl(AnyEvent) if we have a versioned one

* Sun Jan 23 2011 Paul Howarth <paul@city-fan.org> - 5.31-1
- Update to 5.31:
  - Work around a POE bug where POE would first poll for new events and invoke
    handlers BEFORE handling the message queue
  - Fix parsing of "domain" statement in resolv.conf
  - stop_read now does just that in TLS mode; see its documentation for caveats
  - Update to common::sense 3.4 warning set
  - AE::Handle had a broken rbuf_max method and missing wbuf_max method
  - New experimental AE::Handle::resettls method

* Fri Jan 21 2011 Paul Howarth <paul@city-fan.org> - 5.30-1
- Import from Fedora
- Update to 5.3
- Filter optional dependencies more aggressively as this module is not
  intended to have any non-core dependencies by itself
- Module remains pure-perl but is now arch-specific as it includes
  arch-specific constants

* Tue Dec 14 2010 Marcela Maslanova <mmaslano@redhat.com> - 5.27-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Sun Aug 22 2010 Nicolas Chauvet <kwizart@gmail.com> - 5.27-1
- Update to 5.271 (rpm version : 5.27)

* Thu Apr 29 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 5.26-1
- Update to 5.261 (rpm version : 5.26)

* Thu Apr 29 2010 Marcela Maslanova <mmaslano@redhat.com> - 5.24-2
- Mass rebuild with perl-5.12.0

* Tue Jan 19 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 5.24-1
- Update to 5.24 (rpm version : 5.24)

* Mon Dec 7 2009 Nicolas Chauvet <kwizart@fedoraproject.org> - 5.22-1
- Update to 5.22 (rpm version : 5.22)

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 5.11-3
- Rebuild against perl 5.10.1

* Mon Aug 31 2009 kwizart < kwizart at gmail.com > - 5.11-2
- Update to 5.112 (rpm version : 5.11)

* Mon Jul 27 2009 kwizart < kwizart at gmail.com > - 4.870-1
- Update to 4.87 (rpm version : 4.870)
- Add more filter requires to workaround rhbz#512553

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.820-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jul 15 2009 kwizart < kwizart at gmail.com > - 4.820-1
- Update to 4.82 (rpm version : 4.820)

* Fri May 29 2009 kwizart < kwizart at gmail.com > - 4.410-1
- Update to 4.41 (rpm version : 4.410)

* Wed Apr 22 2009 kwizart < kwizart at gmail.com > - 4.352-1
- Update to 4.352 (rpm version : same)

* Fri Apr  3 2009 kwizart < kwizart at gmail.com > - 4.350-1
- Update to 4.35 (rpm version : 4.350)

* Thu Mar  5 2009 kwizart < kwizart at gmail.com > - 4.340-1
- Update to 4.34 (rpm version : 4.340)

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.331-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jan 12 2009 kwizart < kwizart at gmail.com > - 4.331-1
- Update to 4.331 (rpm version : same)

* Fri Oct 17 2008 kwizart < kwizart at gmail.com > - 4.300-1
- Update to 4.3 (rpm version : 4.300)

* Tue Oct 14 2008 kwizart < kwizart at gmail.com > - 4.3-1
- Update to 4.3 

* Mon Aug  4 2008 kwizart < kwizart at gmail.com > - 4.231-1
- Update to 4.231 (rpm version : match)

* Fri Jul 18 2008 kwizart < kwizart at gmail.com > - 4.220-1
- Update to 4.22 (rpm version : 4.220)

* Fri Jul 18 2008 kwizart < kwizart at gmail.com > - 4.21-1
- Update to 4.21

* Fri Jul  4 2008 kwizart < kwizart at gmail.com > - 4.161-1
- Update to 4.161

* Mon Jun 23 2008 kwizart < kwizart at gmail.com > - 4.152-1
- Update to 4.152

* Mon Jun  9 2008 kwizart < kwizart at gmail.com > - 4.151-1
- Update to 4.151

* Thu Jun  5 2008 kwizart < kwizart at gmail.com > - 4.13-1
- Update to 4.13

* Tue Jun  3 2008 kwizart < kwizart at gmail.com > - 4.12-1
- Update to 4.12

* Thu May 29 2008 kwizart < kwizart at gmail.com > - 4.1-1
- Update to 4.1

* Tue May 27 2008 kwizart < kwizart at gmail.com > - 3.5-1
- Update to 3.5

* Wed Apr 30 2008 kwizart < kwizart at gmail.com > - 3.3-1
- Initial package for Fedora
